==> jc-1.4.0.tar.gz: org/xml/sax/SAXNotSupportedException.h <==
// public class org.xml.sax.SAXNotSupportedException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c045a3d7d4ce55f1 org_xml_sax_SAXException
// @dep_class 6a215b87e89c25b9 org_xml_sax_SAXNotSupportedException

// header file dependencies
// @dep_header org_xml_sax_SAXException

#include "org/xml/sax/SAXException.h"

#ifndef _JC_org_xml_sax_SAXNotSupportedException_H_
#define _JC_org_xml_sax_SAXNotSupportedException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_org_xml_sax_SAXNotSupportedException$sub_refs	_jc_org_xml_sax_SAXNotSupportedException$sub_refs;
typedef struct _jc_org_xml_sax_SAXNotSupportedException$sub_nonrefs	_jc_org_xml_sax_SAXNotSupportedException$sub_nonrefs;
typedef struct _jc_org_xml_sax_SAXNotSupportedException$refs	_jc_org_xml_sax_SAXNotSupportedException$refs;
typedef struct _jc_org_xml_sax_SAXNotSupportedException$nonrefs	_jc_org_xml_sax_SAXNotSupportedException$nonrefs;
typedef struct _jc_org_xml_sax_SAXNotSupportedException$object	_jc_org_xml_sax_SAXNotSupportedException$object;

typedef const struct _jc_org_xml_sax_SAXNotSupportedException$vmethods	_jc_org_xml_sax_SAXNotSupportedException$vmethods;
typedef const struct _jc_org_xml_sax_SAXNotSupportedException$vtable	_jc_org_xml_sax_SAXNotSupportedException$vtable;
typedef const struct _jc_org_xml_sax_SAXNotSupportedException$vtype	_jc_org_xml_sax_SAXNotSupportedException$vtype;

// Constructors
extern void _jc_org_xml_sax_SAXNotSupportedException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_xml_sax_SAXNotSupportedException$object *);
extern void _jc_org_xml_sax_SAXNotSupportedException$method$_init$c31b894660454d13(_jc_env *, struct _jc_org_xml_sax_SAXNotSupportedException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_org_xml_sax_SAXNotSupportedException$vmethods {
};

// Vtable
struct _jc_org_xml_sax_SAXNotSupportedException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_org_xml_sax_SAXException$vmethods	org_xml_sax_SAXException;
	_jc_org_xml_sax_SAXNotSupportedException$vmethods	org_xml_sax_SAXNotSupportedException;
};

// Vtype
struct _jc_org_xml_sax_SAXNotSupportedException$vtype {
	_jc_type			type;
	_jc_org_xml_sax_SAXNotSupportedException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_xml_sax_SAXNotSupportedException$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_xml_sax_SAXNotSupportedException$refs {
    _jc_org_xml_sax_SAXNotSupportedException$sub_refs	org_xml_sax_SAXNotSupportedException;
    _jc_org_xml_sax_SAXException$sub_refs	org_xml_sax_SAXException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_xml_sax_SAXNotSupportedException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_xml_sax_SAXNotSupportedException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_org_xml_sax_SAXException$sub_nonrefs	org_xml_sax_SAXException;
    _jc_org_xml_sax_SAXNotSupportedException$sub_nonrefs	org_xml_sax_SAXNotSupportedException;
};

// Object instance structure
struct _jc_org_xml_sax_SAXNotSupportedException$object {
	_jc_org_xml_sax_SAXNotSupportedException$refs	refs[0];
	_jc_word		lockword;
	_jc_org_xml_sax_SAXNotSupportedException$vtype	*vtype;
	_jc_org_xml_sax_SAXNotSupportedException$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_xml_sax_SAXNotSupportedException$vtype _jc_org_xml_sax_SAXNotSupportedException$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_xml_sax_SAXNotSupportedException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_xml_sax_SAXNotSupportedException$class_object;

#endif	/* _JC_org_xml_sax_SAXNotSupportedException_H_ */

==> jc-1.4.6.tar.gz: org/xml/sax/SAXNotSupportedException.h <==
// public class org.xml.sax.SAXNotSupportedException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c045a3d7d4ce55f1 org_xml_sax_SAXException
// @dep_class 6a215b87e89c25b9 org_xml_sax_SAXNotSupportedException

// header file dependencies
// @dep_header org_xml_sax_SAXException

#include "org/xml/sax/SAXException.h"

#ifndef _JC_org_xml_sax_SAXNotSupportedException_H_
#define _JC_org_xml_sax_SAXNotSupportedException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_org_xml_sax_SAXNotSupportedException$sub_refs	_jc_org_xml_sax_SAXNotSupportedException$sub_refs;
typedef struct _jc_org_xml_sax_SAXNotSupportedException$sub_nonrefs	_jc_org_xml_sax_SAXNotSupportedException$sub_nonrefs;
typedef struct _jc_org_xml_sax_SAXNotSupportedException$refs	_jc_org_xml_sax_SAXNotSupportedException$refs;
typedef struct _jc_org_xml_sax_SAXNotSupportedException$nonrefs	_jc_org_xml_sax_SAXNotSupportedException$nonrefs;
typedef struct _jc_org_xml_sax_SAXNotSupportedException$object	_jc_org_xml_sax_SAXNotSupportedException$object;

typedef const struct _jc_org_xml_sax_SAXNotSupportedException$vmethods	_jc_org_xml_sax_SAXNotSupportedException$vmethods;
typedef const struct _jc_org_xml_sax_SAXNotSupportedException$vtable	_jc_org_xml_sax_SAXNotSupportedException$vtable;
typedef const struct _jc_org_xml_sax_SAXNotSupportedException$vtype	_jc_org_xml_sax_SAXNotSupportedException$vtype;

// Constructors
extern void _jc_org_xml_sax_SAXNotSupportedException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_xml_sax_SAXNotSupportedException$object *) _JC_JCNI_ATTR;
extern void _jc_org_xml_sax_SAXNotSupportedException$method$_init$c31b894660454d13(_jc_env *, struct _jc_org_xml_sax_SAXNotSupportedException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_org_xml_sax_SAXNotSupportedException$vmethods {
};

// Vtable
struct _jc_org_xml_sax_SAXNotSupportedException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_org_xml_sax_SAXException$vmethods	org_xml_sax_SAXException;
	_jc_org_xml_sax_SAXNotSupportedException$vmethods	org_xml_sax_SAXNotSupportedException;
};

// Vtype
struct _jc_org_xml_sax_SAXNotSupportedException$vtype {
	_jc_type			type;
	_jc_org_xml_sax_SAXNotSupportedException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_xml_sax_SAXNotSupportedException$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_xml_sax_SAXNotSupportedException$refs {
    _jc_org_xml_sax_SAXNotSupportedException$sub_refs	org_xml_sax_SAXNotSupportedException;
    _jc_org_xml_sax_SAXException$sub_refs	org_xml_sax_SAXException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_xml_sax_SAXNotSupportedException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_xml_sax_SAXNotSupportedException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_org_xml_sax_SAXException$sub_nonrefs	org_xml_sax_SAXException;
    _jc_org_xml_sax_SAXNotSupportedException$sub_nonrefs	org_xml_sax_SAXNotSupportedException;
};

// Object instance structure
struct _jc_org_xml_sax_SAXNotSupportedException$object {
	_jc_org_xml_sax_SAXNotSupportedException$refs	refs[0];
	_jc_word		lockword;
	_jc_org_xml_sax_SAXNotSupportedException$vtype	*vtype;
	_jc_org_xml_sax_SAXNotSupportedException$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_xml_sax_SAXNotSupportedException$vtype _jc_org_xml_sax_SAXNotSupportedException$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_xml_sax_SAXNotSupportedException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_xml_sax_SAXNotSupportedException$class_object;

#endif	/* _JC_org_xml_sax_SAXNotSupportedException_H_ */
